@@ -18,7 +18,6 @@ from syned.widget.widget_decorator import WidgetDecorator
 
 from wofry.propagator.wavefront1D.generic_wavefront import GenericWavefront1D
 
-from orangecontrib.wofry.als.util.axo_fit_profile import axo_fit_profile
 import os
 import orangecanvas.resources as resources
 from scipy import interpolate
@@ -123,8 +122,7 @@ class OWRefractiveCorrector1D(WofryWidget):
                           labelWidth=300, valueType=float, orientation="horizontal")
 
         gui.comboBox(self.box_corrector_1, self, "apodization", label="Modify correction profile", labelWidth=350,
-                     items=["No","Apodization with intensity","Apodization with Gaussian",
-                            "JTEC-AXO fit (extrapolated)","JTEC-AXO fit (cropped)"],
+                     items=["No","Apodization with intensity","Apodization with Gaussian"],
                      sendSelectedValue=False, orientation="horizontal",callback=self.set_visible)
         self.apodization_ratio_id = oasysgui.widgetBox(self.box_corrector_1, "", addSpace=False, orientation="horizontal")
         oasysgui.lineEdit(self.apodization_ratio_id, self, "apodization_ratio", "Apodization sigma/window ratio",
@@ -310,37 +308,7 @@ class OWRefractiveCorrector1D(WofryWidget):
             apodization /= apodization.max()
             height *= apodization
             height -= height[0]
-        elif apodization >= 3: # JTEC AXOs
 
-            f = open("tmp_profile.dat","w")
-            for i in range(height.size):
-                f.write("%g %g\n"%(abscissas_on_mirror[i],height[i]))
-            f.close()
-            print("Ideal correction profile written to file: tmp_profile.dat" )
-
-            file_influence = os.path.join(resources.package_dirname("orangecontrib.wofry.als.util"), "data",
-                                                  "aps_axo_influence_functions2019.dat")
-            file_orthonormal = os.path.join(resources.package_dirname("orangecontrib.wofry.als.util"), "data",
-                                                    "aps_axo_orthonormal_functions2019.dat")
-
-            coeffs, abscissas, interpolated, fitted = axo_fit_profile("tmp_profile.dat",
-                                                                      fileout="",
-                                                                      file_influence_functions=file_influence,
-                                                                      file_orthonormal_functions=file_orthonormal,
-                                                                      calculate=False)
-
-            # plot(abscissas_on_mirror, height,
-            #      1e-3 * abscissas, fitted, legend=["Ideal","Fitted"])
-
-            if apodization == 3:
-                f = interpolate.interp1d(1e-3 * abscissas, fitted, fill_value="extrapolate")
-            elif apodization == 4:
-                f = interpolate.interp1d(1e-3 * abscissas, fitted, fill_value=(0,0),bounds_error=False)
-                output_wavefront.clip(1e-3 * abscissas[0] * numpy.sin(grazing_angle), 1e-3 * abscissas[-1] * numpy.sin(grazing_angle))
-
-            height = f(abscissas_on_mirror)
-            # plot(abscissas_on_mirror, height,
-            #      1e-3 * abscissas, fitted, legend=["Extrapolated or Cropped","Fitted"])
         # calculate phase shift from new profile
         phi = -2 * output_wavefront.get_wavenumber() * height * numpy.sin(grazing_angle)
         output_wavefront.add_phase_shift(phi)
@@ -351,9 +319,6 @@ class OWRefractiveCorrector1D(WofryWidget):
             if apodization <= 2:
                 for i in range(height.size):
                     f.write("%g %g\n"%(abscissas_on_mirror[i],height[i]))
-            else:
-                for i in range(fitted.size):
-                    f.write("%g %g\n" % (1e-3 * abscissas[i], fitted[i]))
             f.close()
             print("File written to disk: %s " % file_correction_profile)
 
@@ -394,41 +359,7 @@ def calculate_output_wavefront_after_corrector1D(input_wavefront,grazing_angle=1
         apodization /= apodization.max()
         height *= apodization
         height -= height[0]
-    elif apodization >= 3: # JTEC AXOs
-        from orangecontrib.wofry.als.util.axo_fit_profile import axo_fit_profile
-        import os
-        import orangecanvas.resources as resources
-        from scipy import interpolate
-        
-        f = open("tmp_profile.dat","w")
-        for i in range(height.size):
-            f.write("%g %g\\n"%(abscissas_on_mirror[i],height[i]))
-        f.close()
-        print("Ideal correction profile written to file: tmp_profile.dat" )
 
-        file_influence = os.path.join(resources.package_dirname("orangecontrib.wofry.als.util"), "data",
-                                              "aps_axo_influence_functions2019.dat")
-        file_orthonormal = os.path.join(resources.package_dirname("orangecontrib.wofry.als.util"), "data",
-                                                "aps_axo_orthonormal_functions2019.dat")
-
-        coeffs, abscissas, interpolated, fitted = axo_fit_profile("tmp_profile.dat",
-                                                                  fileout="",
-                                                                  file_influence_functions=file_influence,
-                                                                  file_orthonormal_functions=file_orthonormal,
-                                                                  calculate=False)
-
-        # plot(abscissas_on_mirror, height,
-        #      1e-3 * abscissas, fitted, legend=["Ideal","Fitted"])
-
-        if apodization == 3:
-            f = interpolate.interp1d(1e-3 * abscissas, fitted, fill_value="extrapolate")
-        elif apodization == 4:
-            f = interpolate.interp1d(1e-3 * abscissas, fitted, fill_value=(0,0),bounds_error=False)
-            output_wavefront.clip(1e-3 * abscissas[0] * numpy.sin(grazing_angle), 1e-3 * abscissas[-1] * numpy.sin(grazing_angle))
-
-        height = f(abscissas_on_mirror)
-        # plot(abscissas_on_mirror, height,
-        #      1e-3 * abscissas, fitted, legend=["Extrapolated or Cropped","Fitted"])
     # calculate phase shift from new profile
     phi = -2 * output_wavefront.get_wavenumber() * height * numpy.sin(grazing_angle)
     output_wavefront.add_phase_shift(phi)
@@ -439,9 +370,6 @@ def calculate_output_wavefront_after_corrector1D(input_wavefront,grazing_angle=1
         if apodization <= 2:
             for i in range(height.size):
                 f.write("%g %g\\n"%(abscissas_on_mirror[i],height[i]))
-        else:
-            for i in range(fitted.size):
-                f.write("%g %g\\n" % (1e-3 * abscissas[i], fitted[i]))
         f.close()
         print("File written to disk: %s " % file_correction_profile)
 
